@@ -601,19 +601,23 @@ class wvrgcal_test(unittest.TestCase):
         print('test7')
         print(rvaldict)
 
+        mymsg = str(rvaldict)
+        
         self.rval = rvaldict['success']
 
         if(self.rval):
             self.rval = th.compTables(self.ref[11], self.out, ['WEIGHT','CPARAM'], tolerance=self.comptabtol)
             # ignore WEIGHT because it is empty, CPARAM because it is tested separately
-
+            mymsg += ', comptables successful? '+str(self.rval)
+            
         if(self.rval):
             figfile = ''
             if self.makeplots:
                 figfile='test7'
             self.rval = comp_gainphase(oldctab=self.ref[11], newctab=self.out, myant=-1, spw=[0], tol_deg=self.compangtol, figfile=figfile)
+            mymsg += ', comp_gainphase successful? '+str(self.rval)
 
-        self.assertTrue(self.rval)
+        self.assertTrue(self.rval, msg=mymsg)
 
     def test8(self):
         '''Test 8:  wvrgcal4quasar_10s.ms, tie two times two sources'''
@@ -657,19 +661,23 @@ class wvrgcal_test(unittest.TestCase):
         print('test9')
         print(rvaldict)
 
+        mymsg = str(rvaldict)
+        
         self.rval = rvaldict['success']
 
         if(self.rval):
             self.rval = th.compTables(self.ref[14], self.out, ['WEIGHT','CPARAM'], tolerance=self.comptabtol)
             # ignore WEIGHT because it is empty, CPARAM because it is tested separately
-
+            mymsg += ', comptables successful? '+str(self.rval)
+            
         if(self.rval):
             figfile = ''
             if self.makeplots:
                 figfile='test9'
             self.rval = comp_gainphase(oldctab=self.ref[14], newctab=self.out, myant=-1, spw=[0], tol_deg=self.compangtol, figfile=figfile)
+            mymsg += ', comp_gainphase successful? '+str(self.rval)
 
-        self.assertTrue(self.rval)
+        self.assertTrue(self.rval, msg=mymsg)
 
     def test10(self):
         '''Test 10:  wvrgcal4quasar_10s.ms, statsource, segsource=False, discflagthresh'''
@@ -703,7 +711,8 @@ class wvrgcal_test(unittest.TestCase):
         myvis = self.vis_g
         os.system('cp -R ' + myvis + ' myinput.ms')
         rvaldict = wvrgcal(vis="myinput.ms", caltable=self.out, segsource=False, nsol=5, toffset=0.)
-
+        
+        
         if self.makeref:
             os.system('rm -rf newref/'+self.ref[16])
             os.system('cp -R '+self.out+' newref/'+self.ref[16])
@@ -711,12 +720,15 @@ class wvrgcal_test(unittest.TestCase):
         print('test11')
         print(rvaldict)
 
+        mymsg = str(rvaldict)
+
         self.rval = rvaldict['success']
 
         if(self.rval):
             self.rval = th.compTables(self.ref[16], self.out, ['WEIGHT','CPARAM'], tolerance=self.comptabtol)
             # ignore WEIGHT because it is empty, CPARAM because it is tested separately
-
+            mymsg += ', comptables successful? '+str(self.rval)
+            
         if(self.rval):
             figfile = ''
             if self.makeplots:
@@ -724,8 +736,9 @@ class wvrgcal_test(unittest.TestCase):
             self.rval = comp_gainphase(oldctab=self.ref[16], newctab=self.out, myant=-1, spw=[0],
                                        tol_deg=20*self.compangtol, # the nsol>1 setting leads to a larger impact of the rnd gen dependencies
                                        figfile=figfile)
+            mymsg += ', comp_gainphase successful? '+str(self.rval)
 
-        self.assertTrue(self.rval)
+        self.assertTrue(self.rval, msg=mymsg)
 
     def test12(self):
         '''Test 12:  wvrgcal4quasar_10s.ms, disperse'''
@@ -740,19 +753,23 @@ class wvrgcal_test(unittest.TestCase):
         print('test12')
         print(rvaldict)
 
+        mymsg = str(rvaldict)
+
         self.rval = rvaldict['success']
 
         if(self.rval):
             self.rval = th.compTables(self.ref[17], self.out, ['WEIGHT','CPARAM'], tolerance=self.comptabtol)
             # ignore WEIGHT because it is empty, CPARAM because it is tested separately
-
+            mymsg += ', comptables successful? '+str(self.rval)
+            
         if(self.rval):
             figfile = ''
             if self.makeplots:
                 figfile='test12'
             self.rval = comp_gainphase(oldctab=self.ref[17], newctab=self.out, myant=-1, spw=[0], tol_deg=self.compangtol, figfile=figfile)
-
-        self.assertTrue(self.rval)
+            mymsg += ', comp_gainphase successful? '+str(self.rval)
+            
+        self.assertTrue(self.rval, msg=mymsg)
 
     def test13(self):
         '''Test 13:  wvrgcal4quasar_10s.ms,  totally flagged main table'''
@@ -790,10 +807,13 @@ class wvrgcal_test(unittest.TestCase):
         print('test14-2')
         print(rvaldict2)
 
+        mymsg = str(rvaldict)+',\n'+str(rvaldict2)+'\n'
+        
         self.rval = rvaldict['success'] and rvaldict2['success']
 
         if 'Frac_unflagged' in rvaldict.keys():
             self.rval = self.rval and (rvaldict['Frac_unflagged'][14]>0.9)
+            mymsg += ', frac_unflagged OK? '+str((rvaldict['Frac_unflagged'][14]>0.9))
             
         if(self.rval):
             # antenna DV14 has antenna id 14 (accidentally)
@@ -808,8 +828,9 @@ class wvrgcal_test(unittest.TestCase):
                 rvaldict2['Frac_unflagged'][14]=rvaldict['Frac_unflagged'][14] # The value for antenna 14 is the only one expected to be different
             
             self.rval = (rvaldict==rvaldict2)
+            mymsg += ', ant 14 the only one which is different? '+str(rvaldict==rvaldict2)
                
-        self.assertTrue(self.rval)
+        self.assertTrue(self.rval, msg=mymsg)
         
 
     def test15(self):
@@ -967,18 +988,22 @@ class wvrgcal_test(unittest.TestCase):
         print('test19')
         print(rvaldict)
 
+        mymsg = str(rvaldict)
+        
         self.rval = rvaldict['success']
 
         if(self.rval):
             self.rval = th.compTables(self.ref[19], self.out, ['WEIGHT','CPARAM'],
                                       tolerance=self.comptabtol)
             # ignore WEIGHT because it is empty, CPARAM because it is tested separately
-
+            mymsg += ', comptables successful? '+str(self.rval)
+            
         if(self.rval):
             figfile = ''
             if self.makeplots:
                 figfile='test19'
             self.rval = comp_gainphase(oldctab=self.ref[19], newctab=self.out, myant=-1, spw=[0], tol_deg=self.compangtol, figfile=figfile)
+            mymsg += ', comp_gainphase successful? '+str(self.rval)
 
         self.assertTrue(self.rval)
 
